@@ -48,6 +48,8 @@ DB_SCHEMA = """CREATE TABLE IF NOT EXISTS notebooks(
                      ON notes(title COLLATE NOCASE);
                     CREATE INDEX IF NOT EXISTS idx_notebooks_linked
                      ON notebooks_linked(guid, notebook_guid);
+                    CREATE INDEX IF NOT EXISTS idx_notes_raw_null
+                     ON notes(guid) WHERE raw_note IS NULL;
 """
 
 
@@ -131,6 +133,13 @@ class SqliteStorage(object):
                     " ON notebooks_linked(guid, notebook_guid);"
                 )
 
+        if db_version < 5:
+            with self.db as con4:
+                con4.execute(
+                    "CREATE INDEX IF NOT EXISTS idx_notes_raw_null"
+                    " ON notes(guid) WHERE raw_note IS NULL;"
+                )
+
         self.config.set_config_value("DB_VERSION", str(CURRENT_DB_VERSION))
 
         if need_resync:
